package io.zipcoder.persistenceapp.Controller;

import io.zipcoder.persistenceapp.Model.Home;
import io.zipcoder.persistenceapp.Model.Person;
import io.zipcoder.persistenceapp.Service.HomeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@RestController
public class HomeController {

    @Autowired
    private HomeService homeService;

    @GetMapping("/home")
    public ResponseEntity<Iterable<Home>> getAllHomes() {
        return new ResponseEntity<>(homeService.getAllHomes(), HttpStatus.OK);
    }

    @PostMapping("/home/{address}/{homeNumber}")
    public ResponseEntity<Boolean> createHome(@PathVariable String address, @PathVariable String homeNumber) {
        return new ResponseEntity<>(homeService.createHome(address, homeNumber), HttpStatus.CREATED);
    }

    @PutMapping("/home/{ID}/{personID}")
    public ResponseEntity<Person> addPersonToHome(@PathVariable Long ID, @PathVariable Long personID) {
        return new ResponseEntity<>(homeService.addPersonToHome(ID, personID), HttpStatus.OK);
    }

    @PutMapping("/home/{ID}/{address}/{homeNumber}")
    public ResponseEntity<Home> updateHome(@PathVariable Long ID, @PathVariable String address, @PathVariable String homeNumber) {
        return new ResponseEntity<>(homeService.updateHome(ID, address, homeNumber), HttpStatus.OK);
    }

    @DeleteMapping("/home/ID/{ID}")
    public ResponseEntity<Boolean> deleteHome(@PathVariable Long ID) {
        return new ResponseEntity<>(homeService.deleteHome(ID), HttpStatus.ACCEPTED);
    }

    @GetMapping("/home/ID/{ID}")
    public ResponseEntity<Home> findByID(@PathVariable Long ID) {
        return new ResponseEntity<>(homeService.findById(ID), HttpStatus.OK);
    }

    @GetMapping("/home/homeNumber/{homeNumber}")
    public ResponseEntity<Home> findByHomeNumber(@PathVariable String homeNumber) {
        return new ResponseEntity<>(homeService.findByHomeNumber(homeNumber), HttpStatus.OK);
    }

    @GetMapping("/home/address/{address}")
    public ResponseEntity<Home> findByAddress(@PathVariable String address) {
        return new ResponseEntity<>(homeService.findByAddress(address), HttpStatus.OK);
    }

    @GetMapping("/home/person/{personID}")
    public ResponseEntity<Home> findByPersonID(@PathVariable Long personID) {
        return new ResponseEntity<>(homeService.findByPersonID(personID), HttpStatus.OK);
    }

    @GetMapping("/home/occupants/ID/{ID}")
    public ResponseEntity<Iterable<Person>> getAllHomeOccupants_ById(@PathVariable Long ID) {
        return new ResponseEntity<>(homeService.getAllHomeOccupants_ByID(ID), HttpStatus.OK);
    }

    @GetMapping("/home/occupants/address/{address}")
    public ResponseEntity<Iterable<Person>> getAllHomeOccupants_ByAddress(@PathVariable String address) {
        return new ResponseEntity<>(homeService.getAllHomeOccupants_ByAddress(address), HttpStatus.OK);
    }

    @GetMapping("/home/occupants")
    public ResponseEntity<Iterable<Home>> getHomesWithMultipleOccupants() {
        return new ResponseEntity<>(homeService.getHomesWithMultipleOccupants(), HttpStatus.OK);
    }



}
