package io.zipcoder.persistenceapp.Controller;

import io.zipcoder.persistenceapp.Model.Person;
import io.zipcoder.persistenceapp.Service.PersonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import java.sql.Date;

@RestController
public class PersonController {

    private final PersonService personService;

    @Autowired
    public PersonController(PersonService personService) {
        this.personService = personService;
    }

    @GetMapping("/person")
    public ResponseEntity<Iterable<Person>> getAllPersons() {
        return new ResponseEntity<>(personService.getAllPersons(), HttpStatus.OK);
    }

    @PostMapping("/person/{firstName}/{lastName}/{birthDate}/{mobileNumber}")
    public ResponseEntity<Boolean> createPerson(@PathVariable String firstName, @PathVariable String lastName, @PathVariable Date birthDate, @PathVariable String mobileNumber) {
        return new ResponseEntity<>(personService.createPerson(firstName, lastName, birthDate, mobileNumber), HttpStatus.CREATED);
    }

    @GetMapping("/person/{ID}")
    public ResponseEntity<Person> getPerson(@PathVariable Integer ID) {
        return new ResponseEntity<>(personService.getPerson(ID), HttpStatus.OK);
    }

    @PutMapping("/person/{ID}/{firstName}/{lastName}/{birthDate}/{mobileNumber}")
    public ResponseEntity<Person> updatePerson(@PathVariable Integer ID, @PathVariable String firstName, @PathVariable String lastName, @PathVariable Date birthDate, @PathVariable String mobileNumber) {
        return new ResponseEntity<>(personService.updatePerson(ID, firstName, lastName, birthDate, mobileNumber), HttpStatus.OK);
    }

    @DeleteMapping("/person/{ID}")
    public ResponseEntity<Boolean> deletePerson(@PathVariable Integer ID) {
        return new ResponseEntity<>(personService.deletePerson(ID), HttpStatus.ACCEPTED);
    }

    @GetMapping("/person/reverseLookup/{mobileNumber}")
    public ResponseEntity<Iterable<Person>> getByMobile(@PathVariable String mobileNumber) {
        return new ResponseEntity<>(personService.getByMobile(mobileNumber), HttpStatus.OK);
    }

    @GetMapping("/person/surname/{lastName}")
    public ResponseEntity<Iterable<Person>> getBySurname(@PathVariable String lastName) {
        return new ResponseEntity<>(personService.getBySurname(lastName), HttpStatus.OK);
    }

}
