package io.zipcoder.persistenceapp.Service;

import io.zipcoder.persistenceapp.Model.Home;
import io.zipcoder.persistenceapp.Model.HomeMapper;
import io.zipcoder.persistenceapp.Model.Person;
import io.zipcoder.persistenceapp.Model.PersonMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

@Service
public class HomeService {

    private final JdbcTemplate jdbcTemplate;

    @Autowired
    public HomeService(JdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    public Iterable<Home> getAllHomes() {
        return this.jdbcTemplate.query( "SELECT * FROM HOME", new HomeMapper());
    }

    public Boolean createHome(String address, String homeNumber){
        return this.jdbcTemplate.update("INSERT INTO HOME (ADDRESS, HOMENUMBER) VALUES (?, ?)",
                address, homeNumber) == 1;
    }

    public Person addPersonToHome(Long ID, Long personID){
        this.jdbcTemplate.update("UPDATE PERSON SET HOME_ID = ? WHERE ID = ?", ID, personID);
        return this.jdbcTemplate.queryForObject("SELECT * FROM PERSON WHERE ID = ?", new Object[] { personID }, new PersonMapper());
    }

    public Home updateHome(Long ID, String address, String homeNumber) {
        this.jdbcTemplate.update("UPDATE HOME SET ADDRESS = ? SET HOMENUMBER = ? WHERE ID = ?", address, homeNumber, ID);
        return findById(ID);
    }

    public Boolean deleteHome(Long ID) {
        return this.jdbcTemplate.update("DELETE FROM HOME WHERE ID = ?", ID) == 1;
    }

    public Home findById(Long ID){
        return this.jdbcTemplate.queryForObject("SELECT * FROM HOME WHERE ID = ?", new Object[] { ID }, new HomeMapper());
    }

    public Home findByHomeNumber(String homeNumber){
        return this.jdbcTemplate.queryForObject("SELECT * FROM HOME WHERE HOMENUMBER = ?", new Object[] { homeNumber }, new HomeMapper());
    }

    public Home findByAddress(String address){
        return this.jdbcTemplate.queryForObject("SELECT * FROM HOME WHERE ADDRESS = ?", new Object[] { address }, new HomeMapper());
    }

    public Home findByPersonID(Long personID){
        return this.jdbcTemplate.queryForObject("SELECT HOME.* FROM HOME JOIN PERSON ON HOME.ID = PERSON.HOME_ID WHERE PERSON.ID = ?", new Object[] { personID }, new HomeMapper());
    }

    public Iterable<Person> getAllHomeOccupants_ByID(Long ID) {
        return this.jdbcTemplate.query("SELECT PERSON.* FROM PERSON WHERE HOME_ID = ?", new Object[] { ID}, new PersonMapper());
    }

    public Iterable<Person> getAllHomeOccupants_ByAddress(String address) {
        return this.jdbcTemplate.query("SELECT PERSON.* FROM PERSON JOIN HOME ON HOME.ID = PERSON.HOME_ID WHERE ADDRESS = ?", new Object[] { address }, new PersonMapper());
    }

    public Iterable<Home> getHomesWithMultipleOccupants() {
        return this.jdbcTemplate.query("SELECT HOME.*, COUNT(PERSON.ID) FROM HOME JOIN PERSON ON HOME.ID = PERSON.HOME_ID GROUP BY HOME.ID HAVING COUNT(HOME_ID) > 1", new HomeMapper());
    }

}
