package io.zipcoder.persistenceapp.Service;

import io.zipcoder.persistenceapp.Model.Person;
import io.zipcoder.persistenceapp.Model.PersonMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.sql.Date;

@Service
public class JdbcPersonServiceImpl implements PersonService {

    private final JdbcTemplate jdbcTemplate;

    @Autowired
    public JdbcPersonServiceImpl(JdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    public Iterable<Person> getAllPersons() {
        return this.jdbcTemplate.query( "SELECT * FROM PERSON", new PersonMapper());
    }

    public Boolean createPerson(String firstName, String lastName, Date birthDate, String mobileNumber){
        return this.jdbcTemplate.update("INSERT INTO PERSON (FIRST_NAME, LAST_NAME, BIRTHDAY, MOBILE) VALUES (?, ?, ?, ?)",
                firstName, lastName, birthDate, mobileNumber) == 1;
    }

    public Person getPerson(Integer ID) {
        return this.jdbcTemplate.queryForObject("SELECT * FROM PERSON WHERE ID = ?", new Object[] { ID }, new PersonMapper());
    }

    public Person updatePerson(Integer ID, String firstName, String lastName, Date birthDate, String mobileNumber){
        this.jdbcTemplate.update("UPDATE PERSON SET FIRST_NAME = ? SET LAST_NAME = ? SET BIRTHDAY = ? SET MOBILE = ? WHERE ID = ?", firstName, lastName, birthDate, mobileNumber, ID);
        return getPerson(ID);
    }

    public Boolean deletePerson(Integer ID) {
        return this.jdbcTemplate.update("DELETE FROM PERSON WHERE ID = ?", ID) == 1;
    }

    public Iterable<Person> getByMobile(String mobileNumber) {
        return this.jdbcTemplate.query( "SELECT * FROM PERSON WHERE MOBILE = ?", new Object[] { mobileNumber }, new PersonMapper());
    }

    public Iterable<Person> getBySurname(String lastName) {
        return this.jdbcTemplate.query("SELECT * FROM PERSON WHERE LAST_NAME = ?", new Object[] { lastName }, new PersonMapper());
    }

}
