package io.zipcoder.persistenceapp.Service;

import io.zipcoder.persistenceapp.Model.Person;
import io.zipcoder.persistenceapp.Repository.PersonRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import java.sql.Date;
import java.util.ArrayList;
import java.util.List;

@Primary
@Service
public class JpaPersonServiceImpl implements PersonService {

    private final PersonRepository personRepository;

    @Autowired
    public JpaPersonServiceImpl(PersonRepository personRepository) {
        this.personRepository = personRepository;
    }

    public Iterable<Person> getAllPersons() {
        return this.personRepository.findAll();
    }

    public Boolean createPerson(String firstName, String lastName, Date birthDate, String mobileNumber){
        this.personRepository.save(new Person(firstName, lastName, birthDate, mobileNumber));
        return true;
    }

    public Person getPerson(Integer ID) {
        return this.personRepository.findOne(ID);
    }

    public Person updatePerson(Integer ID, String firstName, String lastName, Date birthDate, String mobileNumber){
        Person person = getPerson(ID);
        person.setFirstName(firstName);
        person.setLastName(lastName);
        person.setBirthDate(birthDate);
        person.setMobileNumber(mobileNumber);
        return this.personRepository.save(person);
    }

    public Boolean deletePerson(Integer ID) {
        this.personRepository.delete(ID);
        return true;
    }

    public Iterable<Person> getByMobile(String mobileNumber) {
        List<Person> ppl = new ArrayList<>();
        for (Person person : personRepository.findAll()) {
            if (mobileNumber.equals(person.getMobileNumber())) {
                ppl.add(person);
            }
        }
        return ppl;
    }

    public Iterable<Person> getBySurname(String lastName) {
        List<Person> ppl = new ArrayList<>();
        for (Person person : personRepository.findAll()) {
            if (lastName.equals(person.getLastName())) {
                ppl.add(person);
            }
        }
        return ppl;
    }

}
